@@ -1,5 +1,5 @@
 use 5.014000;
-use Devel::CallTrace;
+use Devel::CodeObserver;
 use Data::Dumper;
 
 my $dat = {
@@ -15,7 +15,7 @@ my $dat = {
     }
 };
 
-my $tracer = Devel::CallTrace->new();
+my $tracer = Devel::CodeObserver->new();
 my ($retval, $traced) = $tracer->call(sub { $dat->{z}->{m}[0]{n} eq 4 ? 1 : 0 });
 print "RETVAL: $retval\n";
 while (my ($code, $val) = splice @$traced, 0, 2) {
